@@ -4,18 +4,14 @@
 #' @param corr_check Check for data corrections of X-times magnitude. Default is `TRUE`
 #' @return Creates metrics tables for use in covind19.org
 #' @import gt
-#' @import dplyr
+#' @import data.table
 #' @import cli
-#' @importFrom tidyr drop_na
 #' @importFrom glue glue
 #' @importFrom janitor clean_names
 #' @importFrom scales col_bin
 #' @export
 #' @examples
 #' \dontrun{
-#' dat <- get_all_data()
-#' cfr    <- get_cfr(dat) %>% distinct()
-#' r0_est <- get_r_est(dat)
 #' tabs   <- get_metrics_tables()
 #'
 #' tabs$full
@@ -27,8 +23,8 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
 
   set.seed(set_seed <- seed)
   today           <- Sys.Date() - 1
-  dat             <- get_all_data(corr_check = corr_check) %>% dplyr::filter(date <= today)
-  cfr1            <- get_cfr(dat) %>% distinct()
+  dat             <- get_all_data(corr_check = corr_check)[date <= today]
+  cfr1            <- unique(get_cfr(dat))
   r_est           <- get_r_est(dat)
   tp              <- dat
   india_state_pop <- covid19india::pop
@@ -36,102 +32,95 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
   cli::cli_alert_success("data load success!!")
 
   # pull abbrevs -----------
-  use_abbrevs <- tp %>% dplyr::filter(abbrev != "la") %>% dplyr::pull(abbrev) %>% unique() %>% tolower()
+  use_abbrevs <- tolower(unique(tp[abbrev != "la", abbrev]))
 
   # state data ----------
-  vax_dat <- get_state_vax() %>%
-    dplyr::rename(total_vacc = total_doses, pct_at_least_one = pct_one_doses, pct_second = pct_two_doses, daily_vax_dose = daily_doses) %>%
-    tidyr::drop_na() %>%
-    dplyr::mutate(place = ifelse(place == "India", "National estimate", place)) %>%
-    dplyr::filter(date == max(date))
+  vax_dat <- get_state_vax()
+  setnames(vax_dat, c("total_doses", "pct_one_dose", "pct_two_doses", "daily_doses"), c("total_vacc", "pct_at_least_one", "pct_second", "daily_vax_dose"))
 
-  sf <- tp %>%
-    dplyr::group_by(place) %>%
-    dplyr::filter(date > max(as.Date(date)) - 7) %>%
-    dplyr::mutate(
-      dailyTPR7 = daily_cases/daily_tests,
-      dailyCFR7 = daily_deaths/daily_cases
-    ) %>%
-    dplyr::filter(is.finite(dailyTPR7)) %>%
-    dplyr::mutate(dailyTPR7d = mean(dailyTPR7, na.rm = T),
-                  dailyCFR7d = mean(dailyCFR7, na.rm = T)) %>%
-    dplyr::filter(date == max(as.Date(date))) %>%
-    dplyr::distinct(date, .keep_all = TRUE) %>%
-    dplyr::ungroup() %>%
-    dplyr::select(place, total_tests, ppt, dailyTPR7d, dailyCFR7d,
-                  daily_cases, daily_deaths, daily_tests, total_cases, total_deaths) %>%
-    dplyr::left_join(india_state_pop, by = c("place")) %>%
-    dplyr::mutate(
-      place = dplyr::case_when(
-        place == "India" ~ "National estimate",
-        TRUE ~ place
-      ),
-      total_tested = trimws(format(total_tests, big.mark = ",")),
-      ppt          = round(ppt * 100, digits = 2)
-    ) %>%
-    dplyr::left_join(vax_dat, by = c("place"))
+  vax_dat <- na.omit(vax_dat)[,place := data.table::fifelse(place == "India", "National estimate", place)][date == max(date)]
+
+  # TEMPORARY: pull ICMR for the national tests data (expires October 30, 2021)
+  icmr <- fread("https://api.covid19india.org/csv/latest/tested_numbers_icmr_data.csv", showProgress = FALSE)
+
+  setnames(icmr, names(icmr), janitor::make_clean_names(names(icmr)))
+
+  icmr <- icmr[, date := as.Date(tested_as_of, "%d/%m/%Y") - 1][, .(date, total_samples_tested, sample_reported_today)]
+
+  icmr_nat_date_limit <- range(icmr$date, na.rm = TRUE)
+
+  tp_nat <- tp[tp$place == "India" & tp$date <= icmr_nat_date_limit[2] & tp$date >= icmr_nat_date_limit[1]]
+
+  icmr    <- utils::tail(icmr, 30)
+  tp_nat  <- utils::tail(tp_nat, 30)
+  tp_rest <- tp[tp$place != "India"]
+
+  tp_nat$daily_tests <- as.numeric(icmr$sample_reported_today)
+  tp_nat[, tpr := daily_cases / daily_tests]
+  # tp_nat$tpr         <- tp_nat$daily_cases / tp_nat$daily_tests
+
+  tp <- rbindlist(list(tp_nat, tp_rest))
+
+  setkeyv(tp, cols = "place")
+
+  sf <- unique(tp[, .SD[date > max(as.Date(date) - 7)], by = "place"][
+    , `:=` (dailyTPR7 = daily_cases / daily_tests, dailyCFR7 = daily_deaths / daily_cases)
+  ][
+    , `:=` (dailyTPR7d = mean(dailyTPR7, na.rm = T), dailyCFR7d = mean(dailyCFR7, na.rm = T)), by = "place"
+  ][, .SD[date == max(date)], by = "place"])
+
+  sf <- sf[, .(place, total_tests, ppt, dailyTPR7d, dailyCFR7d,
+               daily_cases, daily_deaths, daily_tests, total_cases, total_deaths)]
+
+  sf <- data.table::merge.data.table(sf, covid19india::pop, by = "place", all.x = TRUE)[
+    , `:=` (place = data.table::fifelse(place == "India", "National estimate", place),
+            total_tested = trimws(format(total_tests, big.mark = ",")),
+            ppt = round(ppt * 100, digits = 2))
+  ]
+
+  sf <- data.table::merge.data.table(sf, vax_dat, by = "place", all.x = TRUE)
 
   # table ----------
-  tib <- cfr1 %>%
-    dplyr::distinct(place, .keep_all = TRUE) %>%
-    dplyr::left_join(r_est %>%
-                       dplyr::mutate(place = recode(place, "India" = "National estimate")),
-                     by = c("place")) %>%
-    dplyr::left_join(tp %>%
-                       extract_latest(cols = c("tpr")),
-                     by = c("place")) %>%
-    dplyr::left_join(sf, by = c("place")) %>%
-    dplyr::mutate(perc_vaccine   = pct_at_least_one,
-                  total_vacc     = format(total_vacc, big.mark = ","),
-                  daily_cases    = format(daily_cases, big.mark = ","),
-                  daily_deaths   = format(daily_deaths, big.mark = ","),
-                  daily_tests    = format(daily_tests, big.mark = ","),
-                  daily_vax_dose = format(daily_vax_dose, big.mark = ","),
-                  cases          = format(total_cases, big.mark = ","),
-                  deaths         = format(total_deaths, big.mark = ",")) %>%
-    dplyr::rename(
-      `# daily new cases`              = daily_cases,
-      `# daily new deaths`             = daily_deaths,
-      `7-day average daily TPR`        = dailyTPR7d,
-      `7-day average daily CFR`        = dailyCFR7d,
-      R                                = r,
-      `daily tests`                    = daily_tests,
-      `daily vaccine doses`            = daily_vax_dose,
-      Location                         = place,
-      CFR                              = cfr,
-      `total cases`                    = cases,
-      `total deaths`                   = deaths,
-      `TPR`                            = tpr,
-      `Total tested`                   = total_tested,
-      `Percent with at least one dose` = perc_vaccine,
-      `Total doses`                    = total_vacc,
-      `% pop. with two shots`          = pct_second,
-      `% pop. with at least one shot`  = pct_at_least_one
-    ) %>%
-    dplyr::arrange(dplyr::desc(`total cases`)) %>%
-    dplyr::mutate(
+  tib <- cfr1[, .(place, cfr)]
+
+  tib <- data.table::merge.data.table(tib, r_est[, place := data.table::fifelse(place == "India", "National estimate", place)][, .(place, r)], by = "place", all.x = TRUE)
+
+  tib <- data.table::merge.data.table(tib, extract_latest(tp, clmns = c("tpr")), by = "place", all.x = TRUE)
+
+  tib <- data.table::merge.data.table(tib, sf, by = "place", all.x = TRUE)[
+    , `:=` (
+      perc_vaccine   = pct_at_least_one,
+      total_vacc     = format(total_vacc, big.mark = ","),
+      daily_cases    = format(daily_cases, big.mark = ","),
+      daily_deaths   = format(daily_deaths, big.mark = ","),
+      daily_tests    = format(daily_tests, big.mark = ","),
+      daily_vax_dose = format(daily_vax_dose, big.mark = ","),
+      cases          = format(total_cases, big.mark = ","),
+      deaths         = format(total_deaths, big.mark = ",")
+    )
+  ]
+
+  setnames(tib,
+           old = c( "daily_cases", "daily_deaths", "dailyTPR7d", "dailyCFR7d", "r", "daily_tests", "daily_vax_dose", "place", "cfr", "cases", "deaths", "tpr", "total_tested", "perc_vaccine", "total_vacc", "pct_second", "pct_at_least_one"),
+           new = c("# daily new cases", "# daily new deaths", "7-day average daily TPR", "7-day average daily CFR", "R", "daily tests", "daily vaccine doses", "Location", "CFR", "total cases","total deaths", "TPR", "Total tested", "Percent with at least one dose", "Total doses", "% pop. with two shots", "% pop. with at least one shot"))
+
+  tib <- tib[order(-`total_cases`)][
+    , `:=` (
       `7-day average daily CFR`       = round(`7-day average daily CFR`, digits = 3),
       `% pop. with two shots`         = round(`% pop. with two shots`, digits = 2),
       `% pop. with at least one shot` = round(`% pop. with at least one shot`, digits = 2)
-    ) %>%
-    dplyr::select(`# daily new cases`, `# daily new deaths`, `7-day average daily TPR`,
-                  `7-day average daily CFR`, Location, R, `daily tests`,
-                  `daily vaccine doses`, CFR, `Total tested`, `total cases`,
-                  `total deaths`, `Total doses`, `TPR`,`% pop. with two shots`,
-                  `% pop. with at least one shot`)
+    )
+  ][
+    , .(`# daily new cases`, `# daily new deaths`, `7-day average daily TPR`,
+        `7-day average daily CFR`, Location, R, `daily tests`,
+        `daily vaccine doses`, CFR, `Total tested`, `total cases`,
+        `total deaths`, `Total doses`, `TPR`,`% pop. with two shots`,
+        `% pop. with at least one shot`)
+  ]
 
-  tib <- tib %>%
-    dplyr::select(-`Total tested`) %>%
-    dplyr::mutate(Location = case_when(
-      Location == "National estimate" ~ "India",
-      TRUE ~ Location)
-    ) %>%
-    dplyr::distinct() %>%
-    dplyr::mutate_if(is.character, trimws) %>%
-    tidyr::drop_na(`# daily new cases`) %>%
-    dplyr::filter(`# daily new cases` != "NA")
+  tib <- unique(tib[, !c("Total tested")][, Location := data.table::fifelse(Location == "National estimate", "India", Location)])
 
-  source_note_text <- glue(
+  source_note_text <- glue::glue(
     "**\uA9 COV-IND-19 Study Group**<br>**Source data:** covid19india.org<br>
       **Notes:** Cells highlighted in green indicates good performance for given metric while red indicates need for improvement.
       Only states/union territories with the highest cumulative case counts as of {format(today, '%B %e')} are shown.
@@ -155,7 +144,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
     tab_style(
       style = cell_text(
         size      = px(12),
-        color     = "#999",
+        color     = "#999999",
         font      = "helvetica",
         transform = "uppercase"
       ),
@@ -212,7 +201,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
     tab_style(
       style = cell_text(
         size      = px(14),
-        color     = "#999",
+        color     = "#999999",
         font      = "helvetica",
         transform = "uppercase"
       ),
@@ -259,9 +248,9 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
   cli::cli_alert_success("full table made")
 
   # new table
-  point_in_time <- tib %>%
-    select(-`total cases`, -`total deaths`, -`TPR`, -CFR,
-           -`Total doses`, -`% pop. with two shots`, -`% pop. with at least one shot`) %>%
+  point_in_time <- tib[, !c("total cases", "total deaths", "TPR", "CFR",
+                            "Total doses", "% pop. with two shots",
+                            "% pop. with at least one shot")] %>%
     gt() %>%
     # format table body text
     tab_style(
@@ -276,7 +265,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
     tab_style(
       style = cell_text(
         size      = px(12),
-        color     = "#999",
+        color     = "#999999",
         font      = "helvetica",
         transform = "uppercase"
       ),
@@ -327,7 +316,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
     tab_style(
       style = cell_text(
         size      = px(14),
-        color     = "#999",
+        color     = "#999999",
         font      = "helvetica",
         transform = "uppercase"
       ),
@@ -361,9 +350,8 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
 
   cli::cli_alert_success("point-in-time table made")
 
-  cumulative <- tib %>%
-    select(-`# daily new cases`, -`# daily new deaths`, -`7-day average daily TPR`,
-           -`7-day average daily CFR`, -R, -`daily tests`, -`daily vaccine doses`) %>%
+  cumulative <- tib[, !c("# daily new cases", "# daily new deaths", "7-day average daily TPR",
+                         "7-day average daily CFR", "R", "daily tests", "daily vaccine doses")] %>%
     gt() %>%
     # format table body text
     tab_style(
@@ -378,7 +366,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
     tab_style(
       style = cell_text(
         size      = px(12),
-        color     = "#999",
+        color     = "#999999",
         font      = "helvetica",
         transform = "uppercase"
       ),
@@ -425,7 +413,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
     tab_style(
       style = cell_text(
         size      = px(14),
-        color     = "#999",
+        color     = "#999999",
         font      = "helvetica",
         transform = "uppercase"
       ),
@@ -451,12 +439,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
 
   if (!is.null(top20)) {
 
-    t20_tib <- tib %>%
-      dplyr::left_join(
-        pop %>% dplyr::select(-population), by = c("Location" = "place")
-      ) %>%
-      dplyr::filter(abbrev %in% unique(c(top20, "tt"))) %>%
-      dplyr::select(-abbrev)
+    t20_tib <- data.table::merge.data.table(tib, covid19india::pop[, !c("population")], by.x = "Location", by.y = "place")[abbrev %in% unique(c(top20, "tt"))][, !c("abbrev")][]
 
     source_note_text <- glue(
       "**\uA9 COV-IND-19 Study Group**<br>**Source data:** covid19india.org<br>
@@ -482,7 +465,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
       tab_style(
         style = cell_text(
           size      = px(12),
-          color     = "#999",
+          color     = "#999999",
           font      = "helvetica",
           transform = "uppercase"
         ),
@@ -539,7 +522,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
       tab_style(
         style = cell_text(
           size      = px(14),
-          color     = "#999",
+          color     = "#999999",
           font      = "helvetica",
           transform = "uppercase"
         ),
@@ -586,9 +569,9 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
     cli::cli_alert_success("full top 20 table made")
 
     # new table
-    t20_point_in_time <- t20_tib %>%
-      select(-`total cases`, -`total deaths`, -`TPR`, -CFR,
-             -`Total doses`, -`% pop. with two shots`, -`% pop. with at least one shot`) %>%
+    t20_point_in_time <- t20_tib[, !c("total cases", "total deaths", "TPR", "CFR",
+                                      "Total doses", "% pop. with two shots",
+                                      "% pop. with at least one shot")] %>%
       gt() %>%
       # format table body text
       tab_style(
@@ -603,7 +586,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
       tab_style(
         style = cell_text(
           size      = px(12),
-          color     = "#999",
+          color     = "#999999",
           font      = "helvetica",
           transform = "uppercase"
         ),
@@ -654,7 +637,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
       tab_style(
         style = cell_text(
           size      = px(14),
-          color     = "#999",
+          color     = "#999999",
           font      = "helvetica",
           transform = "uppercase"
         ),
@@ -688,9 +671,8 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
 
     cli::cli_alert_success("top 20 point-in-time table made")
 
-    t20_cumulative <- t20_tib %>%
-      select(-`# daily new cases`, -`# daily new deaths`, -`7-day average daily TPR`,
-             -`7-day average daily CFR`, -R, -`daily tests`, -`daily vaccine doses`) %>%
+    t20_cumulative <- t20_tib[, !c("# daily new cases", "# daily new deaths", "7-day average daily TPR",
+                                   "7-day average daily CFR", "R", "daily tests", "daily vaccine doses")] %>%
       gt() %>%
       # format table body text
       tab_style(
@@ -705,7 +687,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
       tab_style(
         style = cell_text(
           size      = px(12),
-          color     = "#999",
+          color     = "#999999",
           font      = "helvetica",
           transform = "uppercase"
         ),
@@ -752,7 +734,7 @@ get_metrics_tables <- function(seed = 46342, top20 = NULL, corr_check = TRUE) {
       tab_style(
         style = cell_text(
           size      = px(14),
-          color     = "#999",
+          color     = "#999999",
           font      = "helvetica",
           transform = "uppercase"
         ),
